@@ -1,8 +1,7 @@
-package    # hide from PAUSE
-  WWW::Google::Contacts::Meta::Attribute::Trait::XmlField;
+package WWW::Google::Contacts::Meta::Attribute::Trait::XmlField;
 
 BEGIN {
-    $WWW::Google::Contacts::Meta::Attribute::Trait::XmlField::VERSION = '0.10';
+    $WWW::Google::Contacts::Meta::Attribute::Trait::XmlField::VERSION = '0.11';
 }
 
 use Moose::Role;
@@ -37,7 +36,7 @@ no Moose::Role;
 package Moose::Meta::Attribute::Custom::Trait::XmlField;
 
 BEGIN {
-    $Moose::Meta::Attribute::Custom::Trait::XmlField::VERSION = '0.10';
+    $Moose::Meta::Attribute::Custom::Trait::XmlField::VERSION = '0.11';
 }
 
 sub register_implementation {
@@ -56,7 +55,7 @@ WWW::Google::Contacts::Meta::Attribute::Trait::XmlField
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHORS
 
