@@ -1,8 +1,7 @@
-package    # hide from PAUSE
-  WWW::Google::Contacts::Type::Birthday;
+package WWW::Google::Contacts::Type::Birthday;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Birthday::VERSION = '0.10';
+    $WWW::Google::Contacts::Type::Birthday::VERSION = '0.11';
 }
 
 use Moose;
@@ -31,7 +30,7 @@ WWW::Google::Contacts::Type::Birthday
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHORS
 
