@@ -1,8 +1,7 @@
-package    # hide from PAUSE
-  WWW::Google::Contacts::Type::Category;
+package WWW::Google::Contacts::Type::Category;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Category::VERSION = '0.10';
+    $WWW::Google::Contacts::Type::Category::VERSION = '0.11';
 }
 
 use Moose;
@@ -44,7 +43,7 @@ WWW::Google::Contacts::Type::Category
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHORS
 
