@@ -1,8 +1,7 @@
-package    # hide from PAUSE
-  WWW::Google::Contacts::Type::ExternalId;
+package WWW::Google::Contacts::Type::ExternalId;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::ExternalId::VERSION = '0.10';
+    $WWW::Google::Contacts::Type::ExternalId::VERSION = '0.11';
 }
 
 use Moose;
@@ -43,7 +42,7 @@ WWW::Google::Contacts::Type::ExternalId
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHORS
 
