@@ -1,8 +1,7 @@
-package    # hide from PAUSE
-  WWW::Google::Contacts::Type::Name;
+package WWW::Google::Contacts::Type::Name;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Name::VERSION = '0.10';
+    $WWW::Google::Contacts::Type::Name::VERSION = '0.11';
 }
 
 use Moose;
@@ -88,7 +87,7 @@ WWW::Google::Contacts::Type::Name
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHORS
 
