@@ -1,8 +1,7 @@
-package    # hide from PAUSE
-  WWW::Google::Contacts::Type::Priority;
+package WWW::Google::Contacts::Type::Priority;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Priority::VERSION = '0.10';
+    $WWW::Google::Contacts::Type::Priority::VERSION = '0.11';
 }
 
 use Moose;
@@ -34,7 +33,7 @@ WWW::Google::Contacts::Type::Priority
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHORS
 
