@@ -1,8 +1,7 @@
-package    # hide from PAUSE
-  WWW::Google::Contacts::Type::When;
+package WWW::Google::Contacts::Type::When;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::When::VERSION = '0.10';
+    $WWW::Google::Contacts::Type::When::VERSION = '0.11';
 }
 
 use Moose;
@@ -41,7 +40,7 @@ WWW::Google::Contacts::Type::When
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHORS
 
